# Terminal Text
A simple python module that allows you send text messages to your phone.

### Installation
- `pip install terminal-text` install the module
- export `TWILIO_API = XXXXXXXXXXXXXXX` 
- export `TWILIO_SID = XXXXXXXXXXXXXX`
- export `YOUR_NUMBER` , the number you want to send text to.
- export `TWILIO_NUMBER` The number given by twilio.

### Usage
- `termtext -m "Enter Message"`
- `termtext --media "image_link"`


### Contribution
- This module is available under MIT license.
- if you would like to contribute to this module feel free to fork and create a PR.

##### DEMO
[![asciicast](https://asciinema.org/a/6proHUTeUQ2m5LcolFZrZIbl9.svg)](https://asciinema.org/a/6proHUTeUQ2m5LcolFZrZIbl9)
